==> qtermwidget_1.4.0.orig.tar.xz: qtermwidget-1.4.0/lib/translations/qtermwidget_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>Konsole::Session</name>
    <message>
        <location filename="../Session.cpp" line="454"/>
        <source>Bell in session &apos;%1&apos;</source>
        <translation>צלצול בהפעלה ‚%1’</translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="606"/>
        <source>Session &apos;%1&apos; exited with code %2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="608"/>
        <source>Session &apos;%1&apos; crashed.</source>
        <translation>ההפעלה ‚%1’ קרסה.</translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="613"/>
        <source>Session &apos;%1&apos; exited unexpectedly.</source>
        <translation>ההפעלה ‚%1’ נסגרה במפתיע.</translation>
    </message>
</context>
<context>
    <name>Konsole::TerminalDisplay</name>
    <message>
        <location filename="../TerminalDisplay.cpp" line="1275"/>
        <source>Size: XXX x XXX</source>
        <translation>גודל: XXX × XXX</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="1287"/>
        <source>Size: %1 x %2</source>
        <translation>גודל: %1 × %2</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="2787"/>
        <source>Paste multiline text</source>
        <translation>הדבקת מקבץ שורות</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="2788"/>
        <source>Are you sure you want to paste this text?</source>
        <translation>להדביק את הטקסט הזה?</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="3258"/>
        <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;הפלט &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;הושהה&lt;/a&gt; בלחיצה על Ctrl+S.  יש ללחוץ על &lt;b&gt;Ctrl+Q&lt;/b&gt; כדי להמשיך.&lt;/qt&gt;</translation>
    </message>
</context>
<context>
    <name>Konsole::Vt102Emulation</name>
    <message>
        <location filename="../Vt102Emulation.cpp" line="1121"/>
        <source>No keyboard translator available.  The information needed to convert key presses into characters to send to the terminal is missing.</source>
        <translation>אין מתרגם מקלדת זמין.  המידע שנדרש לצורך המרת לחיצות מקשים לתווים לשליחה למסוף חסר.</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <location filename="../TerminalDisplay.cpp" line="2794"/>
        <source>Show Details...</source>
        <translation>להציג פרטים…</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../ColorScheme.cpp" line="275"/>
        <location filename="../ColorScheme.cpp" line="290"/>
        <source>Un-named Color Scheme</source>
        <translation>ערכת צבעים ללא שם</translation>
    </message>
    <message>
        <location filename="../ColorScheme.cpp" line="461"/>
        <source>Accessible Color Scheme</source>
        <translation>ערכת צבעים נגישה</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="515"/>
        <source>Open Link</source>
        <translation>פתיחת קישור</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="516"/>
        <source>Copy Link Address</source>
        <translation>העתקת כתובת קישור</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="520"/>
        <source>Send Email To...</source>
        <translation>שליחת דוא״ל אל…</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="521"/>
        <source>Copy Email Address</source>
        <translation>העתקת כתובת דוא״ל</translation>
    </message>
</context>
<context>
    <name>QTermWidget</name>
    <message>
        <location filename="../qtermwidget.cpp" line="469"/>
        <source>Color Scheme Error</source>
        <translation>שגיאת ערכת צבעים</translation>
    </message>
    <message>
        <location filename="../qtermwidget.cpp" line="470"/>
        <source>Cannot load color scheme: %1</source>
        <translation>לא ניתן לטעון ערכת צבעים: %1</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <location filename="../SearchBar.cpp" line="40"/>
        <source>Match case</source>
        <translation>התאמת רישיות</translation>
    </message>
    <message>
        <location filename="../SearchBar.cpp" line="46"/>
        <source>Regular expression</source>
        <translation>ביטוי רגולרי</translation>
    </message>
    <message>
        <location filename="../SearchBar.cpp" line="50"/>
        <source>Highlight all matches</source>
        <translation>הדגשת כל המופעים</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="14"/>
        <source>SearchBar</source>
        <translation>סרגל חיפוש</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="20"/>
        <source>X</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="32"/>
        <source>Find:</source>
        <translation>חיפוש:</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="42"/>
        <source>&lt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="54"/>
        <source>&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="66"/>
        <source>...</source>
        <translation>…</translation>
    </message>
</context>
</TS>

==> qtermwidget_2.1.0.orig.tar.xz: qtermwidget-2.1.0/lib/translations/qtermwidget_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>Konsole::Session</name>
    <message>
        <location filename="../Session.cpp" line="448"/>
        <source>Bell in session &apos;%1&apos;</source>
        <translation>צלצול בהפעלה ‚%1’</translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="600"/>
        <source>Session &apos;%1&apos; exited with code %2.</source>
        <translation>ההפעלה ‚%1’ הסתיימה עם הקוד %2.</translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="602"/>
        <source>Session &apos;%1&apos; crashed.</source>
        <translation>ההפעלה ‚%1’ קרסה.</translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="607"/>
        <source>Session &apos;%1&apos; exited unexpectedly.</source>
        <translation>ההפעלה ‚%1’ נסגרה במפתיע.</translation>
    </message>
</context>
<context>
    <name>Konsole::TerminalDisplay</name>
    <message>
        <location filename="../TerminalDisplay.cpp" line="1278"/>
        <source>Size: XXX x XXX</source>
        <translation>גודל: XXX × XXX</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="1290"/>
        <source>Size: %1 x %2</source>
        <translation>גודל: %1 × %2</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="2790"/>
        <source>Paste multiline text</source>
        <translation>הדבקת מקבץ שורות</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="2791"/>
        <source>Are you sure you want to paste this text?</source>
        <translation>להדביק את הטקסט הזה?</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="3261"/>
        <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;הפלט &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;הושהה&lt;/a&gt; בלחיצה על Ctrl+S.  יש ללחוץ על &lt;b&gt;Ctrl+Q&lt;/b&gt; כדי להמשיך.&lt;/qt&gt;</translation>
    </message>
</context>
<context>
    <name>Konsole::Vt102Emulation</name>
    <message>
        <location filename="../Vt102Emulation.cpp" line="1106"/>
        <source>No keyboard translator available.  The information needed to convert key presses into characters to send to the terminal is missing.</source>
        <translation>אין מתרגם מקלדת זמין.  המידע שנדרש לצורך המרת לחיצות מקשים לתווים לשליחה למסוף חסר.</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <location filename="../TerminalDisplay.cpp" line="2797"/>
        <source>Show Details...</source>
        <translation>להציג פרטים…</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../ColorScheme.cpp" line="275"/>
        <location filename="../ColorScheme.cpp" line="290"/>
        <source>Un-named Color Scheme</source>
        <translation>ערכת צבעים ללא שם</translation>
    </message>
    <message>
        <location filename="../ColorScheme.cpp" line="461"/>
        <source>Accessible Color Scheme</source>
        <translation>ערכת צבעים נגישה</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="520"/>
        <source>Open Link</source>
        <translation>פתיחת קישור</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="521"/>
        <source>Copy Link Address</source>
        <translation>העתקת כתובת קישור</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="525"/>
        <source>Send Email To...</source>
        <translation>שליחת דוא״ל אל…</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="526"/>
        <source>Copy Email Address</source>
        <translation>העתקת כתובת דוא״ל</translation>
    </message>
</context>
<context>
    <name>QTermWidget</name>
    <message>
        <location filename="../qtermwidget.cpp" line="465"/>
        <source>Color Scheme Error</source>
        <translation>שגיאת ערכת צבעים</translation>
    </message>
    <message>
        <location filename="../qtermwidget.cpp" line="466"/>
        <source>Cannot load color scheme: %1</source>
        <translation>לא ניתן לטעון ערכת צבעים: %1</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <location filename="../SearchBar.cpp" line="39"/>
        <source>Match case</source>
        <translation>התאמת רישיות</translation>
    </message>
    <message>
        <location filename="../SearchBar.cpp" line="45"/>
        <source>Regular expression</source>
        <translation>ביטוי רגולרי</translation>
    </message>
    <message>
        <location filename="../SearchBar.cpp" line="49"/>
        <source>Highlight all matches</source>
        <translation>הדגשת כל המופעים</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="14"/>
        <source>SearchBar</source>
        <translation>סרגל חיפוש</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="20"/>
        <source>X</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="32"/>
        <source>Find:</source>
        <translation>חיפוש:</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="42"/>
        <source>&lt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="54"/>
        <source>&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="66"/>
        <source>...</source>
        <translation>…</translation>
    </message>
</context>
</TS>
